@@ -1,14 +1,19 @@
-from .parser import Parser
-from junit_xml import TestSuite, TestCase
 from collections import defaultdict
 from random import randrange
 
+from junit_xml import TestSuite, TestCase
+
+# is it correct import changed from .parser ? I've get error ImportError: attempted relative import with no known parent package
+from secscanner2junit.config import Config
+from secscanner2junit.parser import Parser
+
+
 # See following links to learn more about sast scanners and theirs output
 # https://docs.gitlab.com/ee/user/application_security/sast/analyzers.html#data-provided-by-analyzers
 # https://gitlab.com/gitlab-org/security-products/security-report-schemas/-/blob/master/dist/sast-report-format.json
 class SastParser(Parser):
-    def __init__(self, report, ts_name):
-        super().__init__(report, ts_name)
+    def __init__(self, report, ts_name, config: Config):
+        super().__init__(report, ts_name, config)
         self.p_type = "SAST"
 
     def parse_findings(self, finding, time):
@@ -67,6 +72,7 @@ class SastParser(Parser):
         
         try:
             output += "identifiers.name: {identifiers_name}\n".format(identifiers_name=finding['identifiers'][0]['name'])
+            output += "identifiers.type: {identifiers_type}\n".format(identifiers_type=finding['identifiers'][0]['type'])
             output += "identifiers.value: {identifiers_value}\n".format(identifiers_value=finding['identifiers'][0]['value'])
         except KeyError:
             pass
@@ -88,6 +94,7 @@ class SastParser(Parser):
     def parse(self):
         timing = 0
         findings = self.report['vulnerabilities']
+        findings = self.config.suppress(findings)
         scanners = list(set(f['scanner']['name'] for f in findings))
         testsuites = []
         for scanner in scanners:
@@ -95,3 +102,4 @@ class SastParser(Parser):
             testcases = [self.parse_findings(finding, timing) for finding in rel_find]
             testsuites.append(TestSuite(name=self.ts_name + scanner.replace(' ', '-'), test_cases=testcases))
         return testsuites
+
